@@ -322,12 +322,12 @@ predict.fk_regression <- function(object, xtest = NULL, ...){
     sKy <- ksum(x[o], object$y[o], xtest[otest], object$h, object$betas)
     sKx2 <- ksum(x[o], x[o]^2, xtest[otest], object$h, object$betas)
     sKxy <- ksum(x[o], x[o] * object$y[o], xtest[otest], object$h, object$betas)
-    yhat <- (((sKx2 * sKy - sKx * sKxy) + (sK * sKxy - sKx * sKy) * xtest[otest]) / (sK * sKx2 - sKx^2))[rank(xtest)]
+    yhat <- (((sKx2 * sKy - sKx * sKxy) + (sK * sKxy - sKx * sKy) * xtest[otest]) / (sK * sKx2 - sKx^2))[rank(xtest, ties.method = "first")]
   }
   else{
     sK <- ksum(x[o], numeric(length(x)) + 1, xtest[otest], object$h, object$betas)
     sKy <- ksum(x[o], object$y[o], xtest[otest], object$h, object$betas)
-    yhat <- (sKy / sK)[rank(xtest)]
+    yhat <- (sKy / sK)[rank(xtest, ties.method = "first")]
   }
   yhat
 }
